==> thumbnailer_2.0+15.10.20150527.orig.tar.gz: thumbnailer-2.0+15.10.20150527/plugins/Ubuntu/Thumbnailer.0.1/thumbnailgenerator.h <==
/*
 * Copyright 2013 Canonical Ltd.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors: Jussi Pakkanen <jussi.pakkanen@canonical.com>
*/

#pragma once

#include <memory>

#include <QQuickImageProvider>
#include <thumbnailerinterface.h>

namespace unity
{
namespace thumbnailer
{
namespace qml
{

class ThumbnailGenerator : public QQuickAsyncImageProvider
{
private:
    std::unique_ptr<QDBusConnection> connection;
    std::unique_ptr<ThumbnailerInterface> iface;

public:
    ThumbnailGenerator();
    ThumbnailGenerator(const ThumbnailGenerator& other) = delete;
    const ThumbnailGenerator& operator=(const ThumbnailGenerator& other) = delete;
    ThumbnailGenerator(ThumbnailGenerator&& other) = delete;
    const ThumbnailGenerator& operator=(ThumbnailGenerator&& other) = delete;

    QQuickImageResponse* requestImageResponse(const QString& id, const QSize& requestedSize) override;

protected:
    QString return_default_image_based_on_mime(QString const &id);
};
}
}
}

==> thumbnailer_2.3+15.10.20150915.1.orig.tar.gz: thumbnailer-2.3+15.10.20150915.1/plugins/Ubuntu/Thumbnailer.0.1/thumbnailgenerator.h <==
/*
 * Copyright 2013 Canonical Ltd.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors: Jussi Pakkanen <jussi.pakkanen@canonical.com>
 */

#pragma once

#include <ratelimiter.h>
#include <unity/thumbnailer/qt/thumbnailer-qt.h>

#include <QQuickImageProvider>

#include <memory>

namespace unity
{

namespace thumbnailer
{

namespace qml
{

class ThumbnailGenerator : public QQuickAsyncImageProvider
{
private:
    std::shared_ptr<unity::thumbnailer::qt::Thumbnailer> thumbnailer;
    std::shared_ptr<unity::thumbnailer::RateLimiter> backlog_limiter;

public:
    ThumbnailGenerator(std::shared_ptr<unity::thumbnailer::qt::Thumbnailer> thumbnailer,
                       std::shared_ptr<unity::thumbnailer::RateLimiter> backlog_limiter);
    ThumbnailGenerator(const ThumbnailGenerator& other) = delete;
    const ThumbnailGenerator& operator=(const ThumbnailGenerator& other) = delete;
    ThumbnailGenerator(ThumbnailGenerator&& other) = delete;
    const ThumbnailGenerator& operator=(ThumbnailGenerator&& other) = delete;

    QQuickImageResponse* requestImageResponse(const QString& id, const QSize& requestedSize) override;
};

}  // namespace qml

}  // namespace thumbnailer

}  // namespace unity
